==> spring-cloud-config-server-2.1.3.RELEASE-sources.jar: org/springframework/cloud/config/server/config/VaultConfiguration.java <==
/*
 * Copyright 2018-2019 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.cloud.config.server.config;

import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.cloud.config.server.environment.ConfigTokenProvider;
import org.springframework.cloud.config.server.environment.EnvironmentConfigTokenProvider;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.core.env.Environment;

/**
 * @author Scott Frederick
 */
@Configuration
public class VaultConfiguration {

	private static final String VAULT_TOKEN_PROPERTY_NAME = "spring.cloud.config.server.vault.token";

	@Bean
	@ConditionalOnProperty(VAULT_TOKEN_PROPERTY_NAME)
	public ConfigTokenProvider configTokenProvider(Environment environment) {
		return new EnvironmentConfigTokenProvider(environment, VAULT_TOKEN_PROPERTY_NAME);
	}

}

==> spring-cloud-config-server-2.1.9.RELEASE-sources.jar: org/springframework/cloud/config/server/config/VaultConfiguration.java <==
/*
 * Copyright 2018-2019 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.springframework.cloud.config.server.config;

import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.cloud.config.server.environment.ConfigTokenProvider;
import org.springframework.cloud.config.server.environment.EnvironmentConfigTokenProvider;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.core.env.Environment;

/**
 * @author Scott Frederick
 */
@Configuration
public class VaultConfiguration {

	private static final String VAULT_TOKEN_PROPERTY_NAME = "spring.cloud.config.server.vault.token";

	@Bean
	@ConditionalOnProperty(VAULT_TOKEN_PROPERTY_NAME)
	public ConfigTokenProvider vaultConfigTokenProvider(Environment environment) {
		return new EnvironmentConfigTokenProvider(environment, VAULT_TOKEN_PROPERTY_NAME);
	}

}
